@@ -24,9 +24,6 @@
 #include <KAboutData>
 
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KCrash>
 
 #include <QApplication>
@@ -39,15 +36,8 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QStringList configFiles;
-    configFiles << QStringLiteral("khangmanrc");
-    Kdelibs4ConfigMigrator migrator(QStringLiteral("khangman"));
-    migrator.setConfigFiles(configFiles);
-    migrator.migrate();
-#endif
 
-    KLocalizedString::setApplicationDomain("khangman");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("khangman"));
     QApplication::setApplicationName(QStringLiteral("khangman"));
     QApplication::setApplicationVersion(QStringLiteral(KHANGMAN_VERSION_STRING));
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
